import { Component, OnInit } from '@angular/core';
import { FormGroup, FormControl, Validators } from '@angular/forms';
import { Router } from '@angular/router';
import { AuthService } from '../../services/auth/auth.service';

@Component({
  selector: 'app-login',
  templateUrl: './login.component.html',
  styleUrls: ['./login.component.scss', '../auth.component.scss']
})
export class LoginComponent implements OnInit {
  loginForm = new FormGroup({
    email: new FormControl('', [Validators.email]),
    password: new FormControl('')
  });

  constructor(private router: Router, private auth: AuthService) {
    this.loginForm.addValidators([Validators.required]);
  }

  ngOnInit(): void {
    if (!this.auth.checkAllowed())
      this.router.navigateByUrl("/feed");
  }

  login() {
    if (this.loginForm.valid)
      this.auth.login(
        this.loginForm.get('email')?.value as String,
        this.loginForm.get('password')?.value as String
      )
        .then(() => { this.router.navigateByUrl("/feed") })
        .catch(() => { alert("wrong username or password") });
    else
      alert("missing username or password");
  }
}
