import { Component } from '@angular/core';
import { FormControl, FormGroup, Validators } from '@angular/forms';
import { AuthService } from '../../services/auth/auth.service';
import { Router } from '@angular/router';
import { UserService } from '../../services/data/user.service';

@Component({
  selector: 'app-register',
  templateUrl: './register.component.html',
  styleUrls: ['./register.component.scss', '../auth.component.scss']
})
export class RegisterComponent {
  registerForm = new FormGroup({
    email: new FormControl('', [Validators.email]),
    password: new FormControl(''),
    username: new FormControl(''),
    rePassword: new FormControl('')
  });

  constructor(private router: Router, private auth: AuthService, private user: UserService) {
    this.registerForm.addValidators([Validators.required, Validators.minLength(3)]);
  }

  register() {
    if (this.registerForm.valid)
      this.auth.register(
        this.registerForm.get('email')?.value as String,
        this.registerForm.get('password')?.value as String,
        this.registerForm.get('rePassword')?.value as String,
      )
        .then((cred) => {
          this.user.createUser(
            this.registerForm.get('username')?.value as String,
            this.registerForm.get('email')?.value as String,
            cred.user?.uid as String
          ).then(() => { this.router.navigateByUrl('/auth/login') }).catch(
            () => { alert('failed to create user'); }
          )
        })
        .catch(() => { alert('failed to register') });
    // TODO: better error messages
    else
      alert("failed to register");
  }
}
