import { Injectable, inject } from '@angular/core';
import { AngularFireAuth } from '@angular/fire/compat/auth';
import { ActivatedRouteSnapshot, CanActivateFn, Router, RouterStateSnapshot } from '@angular/router';

@Injectable({
  providedIn: 'root'
})
export class AuthService {
  token?: String;
  constructor(private router: Router, private auth: AngularFireAuth) { }

  checkAllowed() {
    if (this.auth.user)
      return true;
    else {
      this.router.navigateByUrl('/auth/login');
      return false;
    }
  }

  getUser() {
    return this.auth.user;
  }

  login(username: String, password: String) {
    return this.auth.signInWithEmailAndPassword(username as string, password as string);
  }

  logout() {
    return this.auth.signOut();
  }

  register(username: String, password: String, rePassword: String) {
    return this.auth.createUserWithEmailAndPassword(username as string, password as string);
  }
}

export const CheckTokenCanActivate: CanActivateFn = (
  route: ActivatedRouteSnapshot,
  state: RouterStateSnapshot
) => {
  return inject(AuthService).checkAllowed();
}