import { Injectable } from '@angular/core';
import { Post } from '../../../model/Post';
import { AuthService } from '../auth/auth.service';
import { AngularFirestore, Reference } from '@angular/fire/compat/firestore';
import { User } from '../../../model/User';
import { UserService } from './user.service';
import { user } from '@angular/fire/auth';

@Injectable({
  providedIn: 'root'
})
export class PostService {
  constructor(private auth: AuthService, private afs: AngularFirestore) { }

  getFeed(length: Number, start: Number): Promise<Array<Post>> {
    return new Promise<Array<Post>>((resolve, reject) => {
      let posts = Array<Post>();

      if (this.auth.checkAllowed()) {
        this.afs.collection<Post>('post').valueChanges({idField: 'id'}).subscribe(data => {
          data.forEach(i => {
            this.afs.doc((i as any).user).valueChanges().subscribe(user => {
              posts.push({
                user: {
                  username: (user as User).username,
                  email: (user as User).email,
                  picture: (user as User).picture,
                  followed: (user as User).followed
                },
                content: i.content,
                image: i.image,
                likes: i.likes,
                liked: i.liked,
                id: i.id
              })
            });
          });
          resolve(posts);
        });
      } else {
        reject()
      }
    });
  }

  getPosts(username: String, lenght: Number, start: Number) {
    return new Promise<Array<Post>>((resolve, reject) => {
      if (this.auth.checkAllowed()) {
        if (username == undefined) {
          this.auth.getUser().subscribe(cred => {
            this.afs.collection<User>('user', ref => ref.where('id', '==', cred?.uid)).valueChanges().subscribe(user => {
              this.afs.collection<Post>('post', ref => ref.where('user', '==', this.afs.doc('/user/' + user[0].username).ref)).valueChanges({idField:'id'}).subscribe(data => {
                data.forEach(i => {
                  i.user = user[0] as User;
                })
                resolve(data)
              });
            })
          });
        } else {
          this.afs.collection<User>('user').doc(username as string).valueChanges().subscribe(user => {
            this.afs.collection<Post>('post', ref => ref.where('user', '==', this.afs.doc('/user/' + username).ref)).valueChanges({idField:'id'}).subscribe(data => {
              data.forEach(i => {
                i.user = user as User;
              })
              resolve(data)
            });
          });
        }
      } else {
        reject()
      }
    });
  }

  // FIX: duplicate posts
  newPost(content: String, image: String) {
    return new Promise<void>((resolve, reject) => {
      console.log('new post')
      if (this.auth.checkAllowed()) {
        this.auth.getUser().subscribe(data => {
          this.afs.collection<User>('user', ref => ref.where('id', '==', data?.uid)).valueChanges().subscribe(user => {
            this.afs.collection('post').add({
              user: this.afs.doc('/user/' + user[0].username).ref,
              content: content,
              image: image,
            })
              .then(() => resolve())
              .catch(() => reject());
          });
        });
      } else {
        reject();
      }
    });
  }

  removePost(id: String) {
    return this.afs.doc('/post/'+id).delete();
  }
}
